#
# Spec file for NVIDIA kernel module.
#
Summary: NVIDIA kernel module for NVIDIA Architecture support.
Name: NVIDIA_kernel
Version: 0.9
Release: 1
Copyright: NVIDIA Corp. 2000
Group: User Interface/X Hardware Support
Source: NVIDIA_kernel-0.9.tar.gz
URL: http://www.nvidia.com
Distribution: Linux kernel 2.2.X
Vendor: NVIDIA Corp.
Packager: Buildmeister

%description
NVIDIA Architecture support for Linux kernel 2.2.X

%prep
%setup

%build
make

%install
    mkdir -p $RPM_BUILD_ROOT/lib/modules/`uname -r`/video
    cp -f ./NVdriver $RPM_BUILD_ROOT/lib/modules/`uname -r`/video
    
#
# If we are not root, we can live without doing these steps in %install, since we'll do
# them in %post instead.  However, we also mirror them in %install so that users who use
#   rpm --rebuild <package>
# get the proper setup IFF they're logged in as root.

    if [ `id -u` -eq 0 ]; then

        #
        # unload it quietly if already loaded..
        #
        if [ -n "`/sbin/lsmod | grep NVdriver`" ]; then
            /sbin/rmmod NVdriver >/dev/null 2>&1
        fi
        
        #
        # Load the driver to get the major device numbers.
        #
        /sbin/insmod $RPM_BUILD_ROOT/lib/modules/`uname -r`/video/NVdriver || {
            echo Error loading kernel driver
            exit 1
        }
        
        #
        # Read device major numbers.
        #
        set -- `cat /proc/devices | grep --word-regexp nvidia`
        nvnode=$1
        
        #
        # Create device nodes.
        #
        for d in 0 1 2 3
        do
            devfile=/dev/nvidia$d
            rm -f $devfile
            mknod $devfile c $nvnode $d
            chmod 0666 $devfile
        done
        
        devfile=/dev/nvidiactl
        rm -f $devfile
        mknod $devfile c $nvnode 255
        chmod 0666 $devfile
        
        #
        # Automatically load the kernel module using kmod
        # Add our line to /etc/conf.modules (after first deleting any older NVdriver lines)
        #
        confmod="/etc/conf.modules"
        [ -f /etc/modules.conf ] && confmod="/etc/modules.conf"
        
        conftmp=/tmp/conf$$
        
        sed '/^alias.*char-major-.*NVdriver/d' < $confmod > $conftmp
        echo "alias char-major-$nvnode NVdriver" >> $conftmp
        mv $conftmp $confmod
        
        #
        # Add it to the module dependency list.
        #
        /sbin/depmod -a
        
    fi

#
# In %post we re-do the stuff we did in %install, in case the %install stuff failed because the
# installer was not root.
#
%post
    #
    # unload it quietly if already loaded..
    #
    if [ -n "`/sbin/lsmod | grep NVdriver`" ]; then
        /sbin/rmmod NVdriver >/dev/null 2>&1
    fi

    #
    # Load the driver to get the major device numbers.
    #
    /sbin/insmod $RPM_BUILD_ROOT/lib/modules/`uname -r`/video/NVdriver || {
        echo Error loading kernel driver
        exit 1
    }

    #
    # Read device major numbers.
    #
    set -- `cat /proc/devices | grep --word-regexp nvidia`
    nvnode=$1

    #
    # Create device nodes.
    #
    for d in 0 1 2 3
    do
        devfile=/dev/nvidia$d
        rm -f $devfile
        mknod $devfile c $nvnode $d
        chmod 0666 $devfile
    done

    devfile=/dev/nvidiactl
    rm -f $devfile
    mknod $devfile c $nvnode 255
    chmod 0666 $devfile

    #
    # Automatically load the kernel module using kmod
    # Add our line to /etc/conf.modules (after first deleting any older NVdriver lines)
    #
    confmod="/etc/conf.modules"
    [ -f /etc/modules.conf ] && confmod="/etc/modules.conf"

    conftmp=/tmp/conf$$

    sed '/^alias.*char-major-.*NVdriver/d' < $confmod > $conftmp
    echo "alias char-major-$nvnode NVdriver" >> $conftmp
    mv $conftmp $confmod

    #
    # Add it to the module dependency list.
    #
    /sbin/depmod -a
    
    #
    # It worked
    #
    echo NVdriver installed successfully
    echo

    exit 0

%preun
    #
    # unload it quietly if already loaded..
    #
    if [ -n "`/sbin/lsmod | grep NVdriver`" ]; then
        /sbin/rmmod NVdriver >/dev/null 2>&1
    fi

%files
%attr(- root root) /lib/modules/*/video/NVdriver

